@@ -10,7 +10,9 @@
 #'
 #' @param excl Character string (or vector of character strings) denoting parameters to exclude. Used in conjunction with \code{params} argument to select parameters of interest.
 #'
-#' @param ISB Ignore Square Brackets (ISB). Logical specifying whether square brackets should be ignored in the \code{params} and \code{excl} arguments. If \code{TRUE}, square brackets are ignored - input from \code{params} and \code{excl} are otherwise matched exactly. If \code{FALSE}, square brackets are not ignored - input from \code{params} and \code{excl} are matched using grep, which can take arguments in regular expression format. This allows partial names to be used when specifying parameters of interest.
+#' @param ISB Ignore Square Brackets (ISB). Logical specifying whether square brackets should be ignored in the \code{params} and \code{excl} arguments. If \code{TRUE}, square brackets are ignored. If \code{FALSE}, square brackets are not ignored.  This allows partial names to be used when specifying parameters of interest. Use \code{exact} argument to specify whether input from \code{params} and \code{excl} arguments should be matched exactly.
+#'
+#' @param exact Logical specifying whether input from \code{params} and \code{excl} arguments should be matched exactly (after ignoring square brackets if \code{ISB = FALSE}). If \code{TRUE}, input from \code{params} and \code{excl} are matched exactly (after taking \code{ISB} argument into account). If \code{FALSE}, input from \code{params} and \code{excl} are matched using regular expression format (after taking \code{ISB} argument into account).
 #'
 #' @param iter Number of iterations to plot for trace and density plots. The default value is 5000, meaning the last 5000 iterations of the chain will be plotted.
 #'
@@ -90,7 +92,7 @@
 #' @param pos_tick_y_den Numeric vector specifying where ticks on y-axis should be placed for density plots.
 #'
 #' @section Details:
-#' \code{object} argument can be a \code{stanfit} object (\code{rstan} package), a \code{stanreg} object (\code{rstanarm} package), a \code{brmsfit} object (\code{brms} package), an \code{mcmc.list} object (\code{coda} package), an \code{R2jags} model object (\code{R2jags} package), a \code{jagsUI} model object (\code{jagsUI} package), or a matrix containing MCMC chains (each column representing MCMC output for a single parameter, rows representing iterations in the chain). The function automatically detects the object type and proceeds accordingly.
+#' \code{object} argument can be a \code{stanfit} object (\code{rstan} package), a \code{stanreg} object (\code{rstanarm} package), a \code{brmsfit} object (\code{brms} package), an \code{mcmc.list} object (\code{coda} and \code{rjags} packages), \code{mcmc} object (\code{coda} and \code{nimble} packages), \code{list} object (\code{nimble} package), an \code{R2jags} model object (\code{R2jags} package), a \code{jagsUI} model object (\code{jagsUI} package), or a matrix containing MCMC chains (each column representing MCMC output for a single parameter, rows representing iterations in the chain). The function automatically detects the object type and proceeds accordingly.
 #'
 #' Matrices for the \code{priors} argument can be generated using commands such as rnorm, rgamma, runif, etc. Distributions not supported by base R can be generated by using the appropriate packages. It is important to note that some discrepancies between MCMC samplers and R may exist regarding the parameterization of distributions - one example of this is the use of precision in JAGS but standard deviation in R for the 'second parameter' of the normal distribution. If the number of draws for each prior distribution is greater than the total number used for the density plot (\code{iter} times the number of chains), the function will use a subset of the prior draws. If the number of draws for each prior distribution is less than the total number used for the density plot, the function will resample (with replacement) from the prior to obtain the appropriate number of draws.
 #'
@@ -102,23 +104,19 @@
 #' MCMCtrace(MCMC_data, params = 'beta', pdf = FALSE)
 #'
 #' #Traceplots (individual density lines for each chain) just for 'beta[1]'
-#' #'params' takes regular expressions when ISB = FALSE, square brackets 
-#' #must be escaped with '\\'
-#' MCMCtrace(MCMC_data, params = 'beta\\[1\\]', 
-#'           ISB = FALSE, ind = TRUE, pdf = FALSE)
+#' MCMCtrace(MCMC_data, params = 'beta[1]', 
+#'           ISB = FALSE, exact = TRUE, ind = TRUE, pdf = FALSE)
 #'
 #' #Plot prior on top of posterior, calculate prior/posterior overlap (PPO) 
 #' #just for 'beta[1]'
 #' #Add Rhat and n.eff values to density plots
-#' #'params' takes regular expressions when ISB = FALSE, square brackets must 
-#' #be escaped with '\\'
 #' PR <- rnorm(15000, 0, 32)
-#' MCMCtrace(MCMC_data, params = 'beta\\[1\\]', ISB = FALSE, priors = PR, 
-#'           pdf = FALSE, Rhat = TRUE, n.eff = TRUE)
+#' MCMCtrace(MCMC_data, params = 'beta[1]', ISB = FALSE, exact = TRUE, 
+#'           priors = PR, pdf = FALSE, Rhat = TRUE, n.eff = TRUE)
 #'
 #' #Output PPO to R object without plotting trace plots
 #' PR <- rnorm(15000, 0, 32)
-#' PPO <- MCMCtrace(MCMC_data, params = 'beta\\[1\\]', ISB = FALSE, 
+#' PPO <- MCMCtrace(MCMC_data, params = 'beta[1]', ISB = FALSE, exact = TRUE,
 #'                  priors = PR, plot = FALSE, PPO_out = TRUE)
 #' @export
 
@@ -127,6 +125,7 @@ MCMCtrace <- function(object,
                       params = 'all',
                       excl = NULL,
                       ISB = TRUE,
+                      exact = TRUE,
                       iter = 5000,
                       gvals = NULL,
                       priors = NULL,
@@ -173,9 +172,11 @@ MCMCtrace <- function(object,
   {
     warning('Input type matrix - assuming only one chain for each parameter.')
     object1 <- coda::as.mcmc.list(coda::as.mcmc(object))
-    object2 <- MCMCchains(object1, params, excl, ISB, mcmc.list = TRUE)
+    object2 <- MCMCchains(object1, params = params, excl = excl, 
+                          ISB = ISB, exact = exact, mcmc.list = TRUE)
   } else {
-    object2 <- MCMCchains(object, params, excl, ISB, mcmc.list = TRUE)
+    object2 <- MCMCchains(object, params = params, excl = excl, 
+                          ISB = ISB, exact = exact, mcmc.list = TRUE)
   }
   
   
@@ -193,7 +194,7 @@ MCMCtrace <- function(object,
   } else {
     it <- 1 : nrow(object2[[1]])
   }
-  
+
   
   #WARNING/ERROR BLOCK
   if (!is.null(priors))
@@ -466,7 +467,7 @@ MCMCtrace <- function(object,
     {
       for (j in 1:length(np))
       {
-        #j <- 1
+        #j <- 2
         #trace
         tmlt <- do.call('cbind', object2[it, np[j]]) #make into matrix with three chains in columns
         graphics::matplot(it, tmlt, lwd = 1, lty = 1, type = 'l', main = NULL,
@@ -550,22 +551,22 @@ MCMCtrace <- function(object,
           #set axes limits according to inputs
           if (!is.null(priors) & post_zm == FALSE & is.null(ylim) & is.null(xlim))
           {
-            ylim <- range(c(0, max(max_den_y), PPO_y_rng))
-            xlim <- range(c(range(rng_den_x), PPO_x_rng))
+            YLIM2 <- range(c(0, max(max_den_y), PPO_y_rng))
+            XLIM2 <- range(c(range(rng_den_x), PPO_x_rng))
           } else {
             if (!is.null(ylim))
             {
-              ylim <- YLIM
-              xlim <- XLIM
+              YLIM2 <- YLIM
+              XLIM2 <- XLIM
             }
             if (is.null(ylim) & is.null(xlim))
             {
-              ylim <- c(0, max(max_den_y))
-              xlim <- NULL
+              YLIM2 <- c(0, max(max_den_y))
+              XLIM2 <- NULL
             }
           }
           
-          graphics::plot(dens[[1]], xlab = xlab_den, ylab = ylab_den, ylim = ylim, xlim = xlim,
+          graphics::plot(dens[[1]], xlab = xlab_den, ylab = ylab_den, ylim = YLIM2, xlim = XLIM2,
                          lty = lty_den, lwd = lwd_den, main = '',
                          col = grDevices::rgb(red = gg_cols[1,1], green = gg_cols[2,1], 
                                               blue = gg_cols[3,1]),
@@ -599,24 +600,24 @@ MCMCtrace <- function(object,
           #set axes limits according to inputs
           if (!is.null(priors) & post_zm == FALSE & is.null(ylim) & is.null(xlim))
           {
-            ylim <- range(c(range(dens$y), PPO_y_rng))
-            xlim <- range(c(range(dens$x), PPO_x_rng))
+            YLIM2 <- range(c(range(dens$y), PPO_y_rng))
+            XLIM2 <- range(c(range(dens$x), PPO_x_rng))
           } else {
             if (!is.null(ylim))
             {
-              ylim <- YLIM
-              xlim <- XLIM
+              YLIM2 <- YLIM
+              XLIM2 <- XLIM
             }
             if (is.null(ylim) & is.null(xlim))
             {
-              ylim <- NULL
-              xlim <- NULL
+              YLIM2 <- NULL
+              XLIM2 <- NULL
             }
           }
           
           #density plot
-          graphics::plot(dens, xlab = xlab_den, ylab = ylab_den, ylim = ylim, 
-                         main = '', col = COL_DEN, xlim = xlim, lty = lty_den, 
+          graphics::plot(dens, xlab = xlab_den, ylab = ylab_den, ylim = YLIM2, 
+                         main = '', col = COL_DEN, xlim = XLIM2, lty = lty_den, 
                          lwd = lwd_den, cex.axis = sz_tick_txt,
                          cex.lab = sz_ax_txt, xaxt = XAXT_DEN, yaxt = YAXT_DEN)
           
@@ -785,22 +786,22 @@ MCMCtrace <- function(object,
           #set axes limits according to inputs
           if (!is.null(priors) & post_zm == FALSE & is.null(ylim) & is.null(xlim))
           {
-            ylim <- range(c(0, max(max_den_y), PPO_y_rng))
-            xlim <- range(c(range(rng_den_x), PPO_x_rng))
+            YLIM2 <- range(c(0, max(max_den_y), PPO_y_rng))
+            XLIM2 <- range(c(range(rng_den_x), PPO_x_rng))
           } else {
             if (!is.null(ylim))
             {
-              ylim <- YLIM
-              xlim <- XLIM
+              YLIM2 <- YLIM
+              XLIM2 <- XLIM
             }
             if (is.null(ylim) & is.null(xlim))
             {
-              ylim <- c(0, max(max_den_y))
-              xlim <- NULL
+              YLIM2 <- c(0, max(max_den_y))
+              XLIM2 <- NULL
             }
           }
           
-          graphics::plot(dens[[1]], xlab = xlab_den, ylab = ylab_den, ylim = ylim, xlim = xlim,
+          graphics::plot(dens[[1]], xlab = xlab_den, ylab = ylab_den, ylim = YLIM2, xlim = XLIM2,
                          lty = lty_den, lwd = lwd_den, main = '',
                          col = grDevices::rgb(red = gg_cols[1,1], green = gg_cols[2,1], 
                                               blue = gg_cols[3,1]),
@@ -833,24 +834,24 @@ MCMCtrace <- function(object,
           #set axes limits according to inputs
           if (!is.null(priors) & post_zm == FALSE & is.null(ylim) & is.null(xlim))
           {
-            ylim <- range(c(range(dens$y), PPO_y_rng))
-            xlim <- range(c(range(dens$x), PPO_x_rng))
+            YLIM2 <- range(c(range(dens$y), PPO_y_rng))
+            XLIM2 <- range(c(range(dens$x), PPO_x_rng))
           } else {
             if (!is.null(ylim))
             {
-              ylim <- YLIM
-              xlim <- XLIM
+              YLIM2 <- YLIM
+              XLIM2 <- XLIM
             }
             if (is.null(ylim) & is.null(xlim))
             {
-              ylim <- NULL
-              xlim <- NULL
+              YLIM2 <- NULL
+              XLIM2 <- NULL
             }
           }
           
           #density plot
-          graphics::plot(stats::density(rbind(tmlt)), xlab = xlab_den, ylab = ylab_den, ylim = ylim,
-                         col = COL_DEN, xlim = xlim, lty = lty_den, lwd = lwd_den, main = '',
+          graphics::plot(stats::density(rbind(tmlt)), xlab = xlab_den, ylab = ylab_den, ylim = YLIM2,
+                         col = COL_DEN, xlim = XLIM2, lty = lty_den, lwd = lwd_den, main = '',
                          cex.axis = sz_tick_txt, cex.lab = sz_ax_txt, xaxt = XAXT_DEN, 
                          yaxt = YAXT_DEN)
           
